@@ -1,11 +1,16 @@
-from typing import Union, List, Dict, Optional, Text, Tuple, Any  # noqa: F401
+from typing import Union, List, Dict, Optional, Tuple, Any  # noqa: F401
 
 import requests
 
 from pykechain.defaults import API_EXTRA_PARAMS, PARTS_BATCH_LIMIT
 from pykechain.enums import Category, Multiplicity, Classification, PropertyType
 from pykechain.exceptions import APIError, IllegalArgumentError, NotFoundError, MultipleFoundError
-from pykechain.models.input_checks import check_text, check_type, check_list_of_base, check_list_of_dicts
+from pykechain.models.input_checks import (
+    check_text,
+    check_type,
+    check_list_of_base,
+    check_list_of_dicts,
+)
 from pykechain.models.property import Property
 from pykechain.models.tree_traversal import TreeObject
 from pykechain.utils import is_uuid, find, Empty, clean_empty_values, empty
@@ -78,33 +83,42 @@ class Part(TreeObject):
         # we need to run the init of 'Base' instead of 'Part' as we do not need the instantiation of properties
         super().__init__(json, **kwargs)
 
-        self.ref: Text = json.get('ref')
-        self.model_id: Text = json.get("model_id")
-        self.category: Category = json.get('category')
-        self.description: Text = json.get('description')
-        self.multiplicity: Text = json.get('multiplicity')
-        self.classification: Classification = json.get('classification')
+        self.ref: str = json.get("ref")
+        self.model_id: str = json.get("model_id")
+        self.category: Category = json.get("category")
+        self.description: str = json.get("description")
+        self.multiplicity: str = json.get("multiplicity")
+        self.classification: Classification = json.get("classification")
 
-        sorted_properties: List[Dict] = sorted(json['properties'], key=lambda p: p.get('order', 0))
-        self.properties: List[Property] = [Property.create(p, client=self._client) for p in sorted_properties]
+        sorted_properties: List[Dict] = sorted(json["properties"], key=lambda p: p.get("order", 0))
+        self.properties: List[Property] = [
+            Property.create(p, client=self._client) for p in sorted_properties
+        ]
 
-        proxy_data: Optional[Dict] = json.get('proxy_source_id_name', dict())
-        self._proxy_model_id: Optional[Text] = proxy_data.get('id') if proxy_data else None
+        proxy_data: Optional[Dict] = json.get("proxy_source_id_name", dict())
+        self._proxy_model_id: Optional[str] = proxy_data.get("id") if proxy_data else None
 
-    def __call__(self, *args, **kwargs) -> 'Part':
+    def __call__(self, *args, **kwargs) -> "Part":
         """Short-hand version of the `child` method."""
         return self.child(*args, **kwargs)
 
-    def refresh(self, json: Optional[Dict] = None, url: Optional[Text] = None, extra_params: Optional[Dict] = None):
+    def refresh(
+        self,
+        json: Optional[Dict] = None,
+        url: Optional[str] = None,
+        extra_params: Optional[Dict] = None,
+    ):
         """Refresh the object in place."""
         if extra_params is None:
             extra_params = {}
-        extra_params.update(API_EXTRA_PARAMS['part'])
+        extra_params.update(API_EXTRA_PARAMS["part"])
         existing_properties = {p.id: p for p in self.properties}
 
-        super().refresh(json=json,
-                        url=self._client._build_url('part', part_id=self.id),
-                        extra_params=extra_params)
+        super().refresh(
+            json=json,
+            url=self._client._build_url("part", part_id=self.id),
+            extra_params=extra_params,
+        )
 
         # The properties have been recreated anew when refreshing the part, but should be refreshed in-place.
         new_properties = list(self.properties)
@@ -121,7 +135,7 @@ class Part(TreeObject):
     # Family and structure methods
     #
 
-    def property(self, name: Text = None) -> 'AnyProperty':
+    def property(self, name: str = None) -> "AnyProperty":
         """Retrieve the property belonging to this part based on its name, ref or uuid.
 
         :param name: property name, ref or UUID to search for
@@ -153,13 +167,13 @@ class Part(TreeObject):
                 matches = [p for p in self.properties if p.ref == name]
 
         if not matches:
-            raise NotFoundError("Could not find a property with name, id or ref: {}".format(name))
+            raise NotFoundError(f"Could not find a property with name, id or ref: {name}")
         elif len(matches) > 1:
-            raise MultipleFoundError("Found multiple properties with name, id or ref: {}".format(name))
+            raise MultipleFoundError(f"Found multiple properties with name, id or ref: {name}")
         else:
             return matches[0]
 
-    def scope(self) -> 'Scope':
+    def scope(self) -> "Scope":
         """Scope this Part belongs to.
 
         This property will return a `Scope` object. It will make an additional call to the KE-chain API.
@@ -170,7 +184,7 @@ class Part(TreeObject):
         """
         return super().scope
 
-    def parent(self) -> 'Part':
+    def parent(self) -> "Part":
         """Retrieve the parent of this `Part`.
 
         :return: the parent :class:`Part` of this part
@@ -186,7 +200,7 @@ class Part(TreeObject):
             self._parent = self._client.part(pk=self.parent_id, category=self.category)
         return self._parent
 
-    def children(self, **kwargs) -> Union['PartSet', List['Part']]:
+    def children(self, **kwargs) -> Union["PartSet", List["Part"]]:
         """Retrieve the children of this `Part` as `PartSet`.
 
         When you call the :func:`Part.children()` method without any additional filtering options for the children,
@@ -219,7 +233,9 @@ class Part(TreeObject):
         if not kwargs:
             # no kwargs provided is the default, we aim to cache it.
             if self._cached_children is None:
-                self._cached_children = list(self._client.parts(parent=self.id, category=self.category))
+                self._cached_children = list(
+                    self._client.parts(parent=self.id, category=self.category)
+                )
                 for child in self._cached_children:
                     child._parent = self
             return self._cached_children
@@ -227,10 +243,7 @@ class Part(TreeObject):
             # if kwargs are provided, we assume no use of cache as specific filtering on the children is performed.
             return self._client.parts(parent=self.id, category=self.category, **kwargs)
 
-    def child(self,
-              name: Optional[Text] = None,
-              pk: Optional[Text] = None,
-              **kwargs) -> 'Part':
+    def child(self, name: Optional[str] = None, pk: Optional[str] = None, **kwargs) -> "Part":
         """
         Retrieve a child object.
 
@@ -261,7 +274,7 @@ class Part(TreeObject):
             else:
                 part_list = self.children(pk=pk)
 
-        criteria = '\nname: {}\npk: {}\nkwargs: {}'.format(name, pk, kwargs)
+        criteria = f"\nname: {name}\npk: {pk}\nkwargs: {kwargs}"
 
         # If there is only one, then that is the part you are looking for
         if len(part_list) == 1:
@@ -269,9 +282,9 @@ class Part(TreeObject):
 
         # Otherwise raise the appropriate error
         elif len(part_list) > 1:
-            raise MultipleFoundError('{} has more than one matching child.{}'.format(self, criteria))
+            raise MultipleFoundError(f"{self} has more than one matching child.{criteria}")
         else:
-            raise NotFoundError('{} has no matching child.{}'.format(self, criteria))
+            raise NotFoundError(f"{self} has no matching child.{criteria}")
         return part
 
     def populate_descendants(self, batch: int = PARTS_BATCH_LIMIT) -> None:
@@ -297,17 +310,21 @@ class Part(TreeObject):
         >>> bike.populate_descendants(batch=150)
 
         """
-        all_descendants = list(self._client.parts(
-            category=self.category,
-            batch=batch,
-            descendants=self.id,
-        ))[1:]  # remove the part itself, which is returned on index 0
+        all_descendants = list(
+            self._client.parts(
+                category=self.category,
+                batch=batch,
+                descendants=self.id,
+            )
+        )[
+            1:
+        ]  # remove the part itself, which is returned on index 0
 
         self._populate_cached_children(all_descendants=all_descendants, overwrite=True)
 
         return None
 
-    def all_children(self) -> List['Part']:
+    def all_children(self) -> List["Part"]:
         """
         Retrieve a flat list of all descendants, sorted depth-first. Also populates all descendants.
 
@@ -318,7 +335,7 @@ class Part(TreeObject):
             self.populate_descendants()
         return super().all_children()
 
-    def siblings(self, **kwargs) -> Union['PartSet', List['Part']]:
+    def siblings(self, **kwargs) -> Union["PartSet", List["Part"]]:
         """Retrieve the siblings of this `Part` as `PartSet`.
 
         Siblings are other Parts sharing the same parent of this `Part`, including the part itself.
@@ -332,13 +349,14 @@ class Part(TreeObject):
             return self._client.parts(parent=self.parent_id, category=self.category, **kwargs)
         else:
             from pykechain.models.partset import PartSet
+
             return PartSet(parts=[])
 
     #
     # Model and Instance(s) methods
     #
 
-    def model(self) -> 'Part':
+    def model(self) -> "Part":
         """
         Retrieve the model of this `Part` as `Part`.
 
@@ -359,9 +377,9 @@ class Part(TreeObject):
         if self.category == Category.INSTANCE:
             return self._client.model(pk=self.model_id)
         else:
-            raise NotFoundError('Part "{}" already is a model'.format(self))
+            raise NotFoundError(f'Part "{self}" already is a model')
 
-    def instances(self, **kwargs) -> Union['PartSet', List['Part']]:
+    def instances(self, **kwargs) -> Union["PartSet", List["Part"]]:
         """
         Retrieve the instances of this `Part` as a `PartSet`.
 
@@ -388,9 +406,9 @@ class Part(TreeObject):
         if self.category == Category.MODEL:
             return self._client.parts(model=self, category=Category.INSTANCE, **kwargs)
         else:
-            raise NotFoundError('Part "{}" is not a model, hence it has no instances.'.format(self))
+            raise NotFoundError(f'Part "{self}" is not a model, hence it has no instances.')
 
-    def instance(self) -> 'Part':
+    def instance(self) -> "Part":
         """
         Retrieve the single (expected) instance of this 'Part' (of `Category.MODEL`) as a 'Part'.
 
@@ -404,10 +422,12 @@ class Part(TreeObject):
         if len(instances_list) == 1:
             return instances_list[0]
         elif len(instances_list) > 1:
-            raise MultipleFoundError("Part {} has more than a single instance. "
-                                     "Use the `Part.instances()` method".format(self))
+            raise MultipleFoundError(
+                "Part {} has more than a single instance. "
+                "Use the `Part.instances()` method".format(self)
+            )
         else:
-            raise NotFoundError("Part {} has no instance".format(self))
+            raise NotFoundError(f"Part {self} has no instance")
 
     def count_instances(self) -> int:
         """
@@ -417,7 +437,9 @@ class Part(TreeObject):
         :rtype
         """
         if not self.category == Category.MODEL:
-            raise IllegalArgumentError("You can only count the number of instances of a Part with category MODEL")
+            raise IllegalArgumentError(
+                "You can only count the number of instances of a Part with category MODEL"
+            )
 
         response = self._client._request(
             "GET",
@@ -450,10 +472,10 @@ class Part(TreeObject):
     #
 
     def edit(
-            self,
-            name: Optional[Union[Text, Empty]] = empty,
-            description: Optional[Union[Text, Empty]] = empty,
-            **kwargs
+        self,
+        name: Optional[Union[str, Empty]] = empty,
+        description: Optional[Union[str, Empty]] = empty,
+        **kwargs,
     ) -> None:
         """Edit the details of a part (model or instance).
 
@@ -496,9 +518,9 @@ class Part(TreeObject):
 
         """
         update_dict = {
-            'id': self.id,
-            'name': check_text(name, 'name') or self.name,
-            'description': check_text(description, 'description') or str(),
+            "id": self.id,
+            "name": check_text(name, "name") or self.name,
+            "description": check_text(description, "description") or "",
         }
 
         if kwargs:  # pragma: no cover
@@ -506,17 +528,19 @@ class Part(TreeObject):
 
         update_dict = clean_empty_values(update_dict=update_dict)
 
-        response = self._client._request('PUT',
-                                         self._client._build_url('part', part_id=self.id),
-                                         params=API_EXTRA_PARAMS['part'],
-                                         json=update_dict)
+        response = self._client._request(
+            "PUT",
+            self._client._build_url("part", part_id=self.id),
+            params=API_EXTRA_PARAMS["part"],
+            json=update_dict,
+        )
 
         if response.status_code != requests.codes.ok:  # pragma: no cover
-            raise APIError("Could not update Part {}".format(self), response=response)
+            raise APIError(f"Could not update Part {self}", response=response)
 
-        self.refresh(json=response.json().get('results')[0])
+        self.refresh(json=response.json().get("results")[0])
 
-    def proxy_model(self) -> 'Part':
+    def proxy_model(self) -> "Part":
         """
         Retrieve the proxy model of this proxied `Part` as a `Part`.
 
@@ -540,13 +564,16 @@ class Part(TreeObject):
         """
         if self.category != Category.MODEL:
             raise IllegalArgumentError(
-                'Part "{}" is not a product model, therefore it cannot have a proxy model'.format(self))
+                f'Part "{self}" is not a product model, therefore it cannot have a proxy model'
+            )
         if self.classification != Classification.PRODUCT or not self._proxy_model_id:
-            raise NotFoundError('Part "{}" is not a product model, therefore it cannot have a proxy model'.format(self))
+            raise NotFoundError(
+                f'Part "{self}" is not a product model, therefore it cannot have a proxy model'
+            )
 
         return self._client.model(pk=self._proxy_model_id)
 
-    def add(self, model: 'Part', **kwargs) -> 'Part':
+    def add(self, model: "Part", **kwargs) -> "Part":
         """Add a new child instance, based on a model, to this part.
 
         This can only act on instances. It needs a model from which to create the child instance.
@@ -579,7 +606,7 @@ class Part(TreeObject):
 
         return new_instance
 
-    def add_to(self, parent: 'Part', **kwargs) -> 'Part':
+    def add_to(self, parent: "Part", **kwargs) -> "Part":
         """Add a new instance of this model to a part.
 
         This works if the current part is a model and an instance of this model is to be added
@@ -613,7 +640,7 @@ class Part(TreeObject):
 
         return new_instance
 
-    def add_model(self, *args, **kwargs) -> 'Part':
+    def add_model(self, *args, **kwargs) -> "Part":
         """Add a new child model to this model.
 
         In order to prevent the backend from updating the frontend you may add `suppress_kevents=True` as
@@ -633,11 +660,13 @@ class Part(TreeObject):
 
         return new_model
 
-    def add_proxy_to(self,
-                     parent: 'Part',
-                     name: Text,
-                     multiplicity: Multiplicity = Multiplicity.ONE_MANY,
-                     **kwargs) -> 'Part':
+    def add_proxy_to(
+        self,
+        parent: "Part",
+        name: str,
+        multiplicity: Multiplicity = Multiplicity.ONE_MANY,
+        **kwargs,
+    ) -> "Part":
         """Add this model as a proxy to another parent model.
 
         This will add the current model as a proxy model to another parent model. It ensure that it will copy the
@@ -671,7 +700,7 @@ class Part(TreeObject):
         """
         return self._client.create_proxy_model(self, parent, name, multiplicity, **kwargs)
 
-    def add_property(self, *args, **kwargs) -> 'AnyProperty':
+    def add_property(self, *args, **kwargs) -> "AnyProperty":
         """Add a new property to this model.
 
         See :class:`pykechain.Client.create_property` for available parameters.
@@ -686,10 +715,10 @@ class Part(TreeObject):
 
     @staticmethod
     def _parse_update_dict(
-            part: 'Part',
-            properties_fvalues: List[Dict[Text, Any]],
-            update_dict: Dict,
-            creating: bool = False,
+        part: "Part",
+        properties_fvalues: List[Dict[str, Any]],
+        update_dict: Dict,
+        creating: bool = False,
     ) -> Tuple[List[Dict], List[Dict], Dict]:
         """
         Check the content of the update dict and insert them into the properties_fvalues list.
@@ -701,7 +730,9 @@ class Part(TreeObject):
         :return: Tuple with 2 lists of dicts
         :rtype tuple
         """
-        properties_fvalues = check_list_of_dicts(properties_fvalues, 'properties_fvalues') or list()
+        properties_fvalues = (
+            check_list_of_dicts(properties_fvalues, "properties_fvalues") or list()
+        )
         check_type(update_dict, dict, "update_dict")
 
         exception_fvalues = list()
@@ -727,12 +758,14 @@ class Part(TreeObject):
 
         return properties_fvalues, exception_fvalues, parsed_dict
 
-    def add_with_properties(self,
-                            model: 'Part',
-                            name: Optional[Text] = None,
-                            update_dict: Optional[Dict] = None,
-                            properties_fvalues: Optional[List[Dict]] = None,
-                            **kwargs) -> 'Part':
+    def add_with_properties(
+        self,
+        model: "Part",
+        name: Optional[str] = None,
+        update_dict: Optional[Dict] = None,
+        properties_fvalues: Optional[List[Dict]] = None,
+        **kwargs,
+    ) -> "Part":
         """
         Add a new part instance of a model as a child of this part instance and update its properties in one go.
 
@@ -784,9 +817,11 @@ class Part(TreeObject):
             raise APIError("Part should be of category INSTANCE")
 
         if not isinstance(model, Part) or model.category != Category.MODEL:
-            raise IllegalArgumentError('`model` must be a Part object of category MODEL, "{}" is not.'.format(model))
+            raise IllegalArgumentError(
+                f'`model` must be a Part object of category MODEL, "{model}" is not.'
+            )
 
-        instance_name = check_text(name, 'name') or model.name
+        instance_name = check_text(name, "name") or model.name
         properties_fvalues, exception_fvalues, _ = self._parse_update_dict(
             model,
             properties_fvalues,
@@ -794,23 +829,24 @@ class Part(TreeObject):
             creating=True,
         )
 
-        url = self._client._build_url('parts_new_instance')
+        url = self._client._build_url("parts_new_instance")
         response = self._client._request(
-            'POST', url,
-            params=API_EXTRA_PARAMS['parts'],
+            "POST",
+            url,
+            params=API_EXTRA_PARAMS["parts"],
             json=dict(
                 name=instance_name,
                 model_id=model.id,
                 parent_id=self.id,
                 properties_fvalues=properties_fvalues,
-                **kwargs
-            )
+                **kwargs,
+            ),
         )
 
         if response.status_code != requests.codes.created:  # pragma: no cover
-            raise APIError("Could not add to Part {}".format(self), response=response)
+            raise APIError(f"Could not add to Part {self}", response=response)
 
-        new_part_instance: Part = Part(response.json()['results'][0], client=self._client)
+        new_part_instance: Part = Part(response.json()["results"][0], client=self._client)
 
         # ensure that cached children are updated
         if self._cached_children is not None:
@@ -818,13 +854,15 @@ class Part(TreeObject):
 
         # If any values were not set via the json, set them individually
         for exception_fvalue in exception_fvalues:
-            property_model_id = exception_fvalue['model_id']
-            property_instance = find(new_part_instance.properties, lambda p: p.model_id == property_model_id)
-            property_instance.value = exception_fvalue['value']
+            property_model_id = exception_fvalue["model_id"]
+            property_instance = find(
+                new_part_instance.properties, lambda p: p.model_id == property_model_id
+            )
+            property_instance.value = exception_fvalue["value"]
 
         return new_part_instance
 
-    def clone(self, **kwargs) -> 'Part':
+    def clone(self, **kwargs) -> "Part":
         """
         Clone a part.
 
@@ -856,12 +894,12 @@ class Part(TreeObject):
         return self._client._create_clone(parent=parent, part=self, **kwargs)
 
     def copy(
-            self,
-            target_parent: 'Part',
-            name: Optional[Text] = None,
-            include_children: bool = True,
-            include_instances: bool = True,
-    ) -> 'Part':
+        self,
+        target_parent: "Part",
+        name: Optional[str] = None,
+        include_children: bool = True,
+        include_instances: bool = True,
+    ) -> "Part":
         """
         Copy the `Part` to target parent, both of them having the same category.
 
@@ -888,12 +926,15 @@ class Part(TreeObject):
         >>>                    include_instances=True)
 
         """
-        check_type(target_parent, Part, 'target_parent')
+        check_type(target_parent, Part, "target_parent")
 
         if self.category != target_parent.category:
             # Cannot add a model under an instance or vice versa
-            raise IllegalArgumentError("part `{}` and target parent `{}`` must have the same category".
-                                       format(self, target_parent))
+            raise IllegalArgumentError(
+                "part `{}` and target parent `{}`` must have the same category".format(
+                    self, target_parent
+                )
+            )
 
         # to ensure that all properties are retrieved from the backend
         # as it might be the case that a part is retrieved in the context of a widget and there could be a possibility
@@ -913,12 +954,12 @@ class Part(TreeObject):
         return copied_part
 
     def move(
-            self,
-            target_parent: 'Part',
-            name: Optional[Text] = None,
-            include_children: bool = True,
-            include_instances: bool = True,
-    ) -> 'Part':
+        self,
+        target_parent: "Part",
+        name: Optional[str] = None,
+        include_children: bool = True,
+        include_instances: bool = True,
+    ) -> "Part":
         """
         Move the `Part` to target parent, both of them the same category.
 
@@ -961,11 +1002,13 @@ class Part(TreeObject):
 
         return copied_part
 
-    def update(self,
-               name: Optional[Text] = None,
-               update_dict: Optional[Dict] = None,
-               properties_fvalues: Optional[List[Dict]] = None,
-               **kwargs) -> None:
+    def update(
+        self,
+        name: Optional[str] = None,
+        update_dict: Optional[Dict] = None,
+        properties_fvalues: Optional[List[Dict]] = None,
+        **kwargs,
+    ) -> None:
         """
         Edit part name and property values in one go.
 
@@ -1012,16 +1055,14 @@ class Part(TreeObject):
         """
         # dict(name=name, properties=json.dumps(update_dict))) with property ids:value
         # action = 'bulk_update_properties'  # not for KEC3
-        check_text(name, 'name')
+        check_text(name, "name")
 
-        properties_fvalues, exception_fvalues, update_dict = \
-            self._parse_update_dict(self, properties_fvalues, update_dict)
-
-        payload_json = dict(
-            properties_fvalues=properties_fvalues,
-            **kwargs
+        properties_fvalues, exception_fvalues, update_dict = self._parse_update_dict(
+            self, properties_fvalues, update_dict
         )
 
+        payload_json = dict(properties_fvalues=properties_fvalues, **kwargs)
+
         if name:
             payload_json.update(name=name)
 
@@ -1032,20 +1073,21 @@ class Part(TreeObject):
                     prop.value = update_dict[prop.id]
         else:
             response = self._client._request(
-                'PUT', self._client._build_url('part', part_id=self.id),
-                params=API_EXTRA_PARAMS['part'],
-                json=payload_json
+                "PUT",
+                self._client._build_url("part", part_id=self.id),
+                params=API_EXTRA_PARAMS["part"],
+                json=payload_json,
             )
 
             if response.status_code != requests.codes.ok:  # pragma: no cover
-                raise APIError("Could not update Part {}".format(self), response=response)
+                raise APIError(f"Could not update Part {self}", response=response)
 
             # update local properties (without a call)
-            self.refresh(json=response.json()['results'][0])
+            self.refresh(json=response.json()["results"][0])
 
         # If any values can not be set via the json, set them individually
         for exception_fvalue in exception_fvalues:
-            self.property(exception_fvalue['id']).value = exception_fvalue['value']
+            self.property(exception_fvalue["id"]).value = exception_fvalue["value"]
 
     def delete(self) -> None:
         """Delete this part.
@@ -1053,12 +1095,16 @@ class Part(TreeObject):
         :return: None
         :raises APIError: in case an Error occurs
         """
-        response = self._client._request('DELETE', self._client._build_url('part', part_id=self.id))
+        response = self._client._request(
+            "DELETE", self._client._build_url("part", part_id=self.id)
+        )
 
         if response.status_code != requests.codes.no_content:  # pragma: no cover
-            raise APIError("Could not delete Part {}".format(self), response=response)
+            raise APIError(f"Could not delete Part {self}", response=response)
 
-    def order_properties(self, property_list: Optional[List[Union['AnyProperty', Text]]] = None) -> None:
+    def order_properties(
+        self, property_list: Optional[List[Union["AnyProperty", str]]] = None
+    ) -> None:
         """
         Order the properties of a part model using a list of property objects or property names or property id's.
 
@@ -1096,9 +1142,13 @@ class Part(TreeObject):
 
         """
         if self.category != Category.MODEL:
-            raise APIError("Ordering of properties must be done on a Part of category {}.".format(Category.MODEL))
+            raise APIError(
+                f"Ordering of properties must be done on a Part of category {Category.MODEL}."
+            )
 
-        property_ids = check_list_of_base(property_list, Property, 'property_list', method=self.property)
+        property_ids = check_list_of_base(
+            property_list, Property, "property_list", method=self.property
+        )
 
         properties_fvalues = [dict(order=order, id=pk) for order, pk in enumerate(property_ids)]
 
@@ -1108,7 +1158,7 @@ class Part(TreeObject):
     # Utility Functions
     #
 
-    def _repr_html_(self) -> Text:
+    def _repr_html_(self) -> str:
         """
         Represent the part in a HTML table for the use in notebooks.
 
@@ -1117,24 +1167,24 @@ class Part(TreeObject):
         """
         html = [
             "<table width=100%>",
-            "<caption>{}</caption>".format(self.name),
+            f"<caption>{self.name}</caption>",
             "<tr>",
             "<th>Property</th>",
             "<th>Value</th>",
-            "</tr>"
+            "</tr>",
         ]
 
         for prop in self.properties:
-            style = "color:blue;" if prop._json_data.get('output', False) else ""
+            style = "color:blue;" if prop._json_data.get("output", False) else ""
 
-            html.append("<tr style=\"{}\">".format(style))
-            html.append("<td>{}</td>".format(prop.name))
-            html.append("<td>{}</td>".format(prop.value))
+            html.append(f'<tr style="{style}">')
+            html.append(f"<td>{prop.name}</td>")
+            html.append(f"<td>{prop.value}</td>")
             html.append("</tr>")
 
         html.append("</table>")
 
-        return ''.join(html)
+        return "".join(html)
 
     def as_dict(self) -> Dict:
         """
