@@ -1,12 +1,12 @@
 from abc import ABC, abstractmethod
-from typing import Optional, Text, List, TypeVar
+from typing import Optional, List, TypeVar
 
 import requests
 
 from pykechain.exceptions import NotFoundError
 from pykechain.models import BaseInScope
 
-T = TypeVar('T')
+T = TypeVar("T")
 
 
 class TreeObject(BaseInScope, ABC):
@@ -20,7 +20,7 @@ class TreeObject(BaseInScope, ABC):
         """
         super().__init__(json=json, **kwargs)
 
-        self.parent_id: Optional[Text] = json.get('parent_id', None)
+        self.parent_id: Optional[str] = json.get("parent_id", None)
         self._parent: Optional[T] = None
         self._cached_children: Optional[List[T]] = None
 
@@ -28,10 +28,7 @@ class TreeObject(BaseInScope, ABC):
         """Short-hand version of the `child` method."""
         return self.child(*args, **kwargs)
 
-    def child(self: T,
-              name: Optional[Text] = None,
-              pk: Optional[Text] = None,
-              **kwargs) -> T:
+    def child(self: T, name: Optional[str] = None, pk: Optional[str] = None, **kwargs) -> T:
         """
         Retrieve a child object.
 
@@ -89,7 +86,7 @@ class TreeObject(BaseInScope, ABC):
         return all_children
 
     @abstractmethod
-    def count_children(self, method: Text, **kwargs) -> int:
+    def count_children(self, method: str, **kwargs) -> int:
         """
         Retrieve the number of child objects using a light-weight request.
 
@@ -98,27 +95,23 @@ class TreeObject(BaseInScope, ABC):
         :return: number of child objects
         :rtype int
         """
-        parameters = {
-            "scope_id": self.scope_id,
-            "parent_id": self.id,
-            "limit": 1
-        }
+        parameters = {"scope_id": self.scope_id, "parent_id": self.id, "limit": 1}
         if kwargs:
             parameters.update(kwargs)
 
-        response = self._client._request('GET', self._client._build_url(method), params=parameters)
+        response = self._client._request("GET", self._client._build_url(method), params=parameters)
 
         if response.status_code != requests.codes.ok:  # pragma: no cover
-            raise NotFoundError("Could not retrieve {}".format(method))
+            raise NotFoundError(f"Could not retrieve {method}")
 
-        count = response.json()['count']
+        count = response.json()["count"]
 
         return count
 
     def _populate_cached_children(
-            self,
-            all_descendants: List[T],
-            overwrite: Optional[bool] = False,
+        self,
+        all_descendants: List[T],
+        overwrite: Optional[bool] = False,
     ) -> None:
         """
         Fill the `_cached_children` attribute with a list of descendants.
