@@ -20,12 +20,12 @@ class TextEffect(ValidatorEffect):
         :param kwargs: (optional) additional kwargs to pass down
         :type kwargs: dict
         """
-        super(TextEffect, self).__init__(json=json, text=text, **kwargs)
+        super().__init__(json=json, text=text, **kwargs)
         self.text = text
 
     def as_json(self) -> dict:
         """Represent effect as JSON dict."""
-        self._config['text'] = self.text
+        self._config["text"] = self.text
         return self._json
 
 
@@ -47,7 +47,7 @@ class ErrorTextEffect(ValidatorEffect):
         :param kwargs: (optional) additional kwargs to pass down
         :type kwargs: dict
         """
-        super(ErrorTextEffect, self).__init__(json=json, **kwargs)
+        super().__init__(json=json, **kwargs)
 
 
 class HelpTextEffect(ValidatorEffect):
@@ -68,7 +68,7 @@ class HelpTextEffect(ValidatorEffect):
         :param kwargs: (optional) additional kwargs to pass down
         :type kwargs: dict
         """
-        super(HelpTextEffect, self).__init__(json=json, text=text, **kwargs)
+        super().__init__(json=json, text=text, **kwargs)
 
 
 class VisualEffect(ValidatorEffect):
@@ -91,13 +91,13 @@ class VisualEffect(ValidatorEffect):
         :param kwargs: (optional) additional kwargs to pass down
         :type kwargs: dict
         """
-        super(VisualEffect, self).__init__(json=json, **kwargs)
-        self.applyCss = applyCss or self._config.get('applyCss')
+        super().__init__(json=json, **kwargs)
+        self.applyCss = applyCss or self._config.get("applyCss")
 
     def as_json(self) -> dict:
         """Represent effect as JSON dict."""
-        self._config['applyCss'] = self.applyCss
-        self._json['config'] = self._config
+        self._config["applyCss"] = self.applyCss
+        self._json["config"] = self._config
         return self._json
 
 
@@ -107,7 +107,7 @@ class ValidVisualEffect(VisualEffect):
     .. versionadded:: 2.2
     """
 
-    def __init__(self, json=None, applyCss='valid', **kwargs):
+    def __init__(self, json=None, applyCss="valid", **kwargs):
         """Construct an valid visual effect.
 
         :param json: (optional) dict (json) object to construct the object from
@@ -115,7 +115,7 @@ class ValidVisualEffect(VisualEffect):
         :param applyCss: (optional) class to apply, defaults to 'valid'
         :type applyCss: basestring
         """
-        super(ValidVisualEffect, self).__init__(json=json, applyCss=applyCss, **kwargs)
+        super().__init__(json=json, applyCss=applyCss, **kwargs)
 
 
 class InvalidVisualEffect(VisualEffect):
@@ -124,7 +124,7 @@ class InvalidVisualEffect(VisualEffect):
     .. versionadded:: 2.2
     """
 
-    def __init__(self, json=None, applyCss='invalid', **kwargs):
+    def __init__(self, json=None, applyCss="invalid", **kwargs):
         """Construct an invalid visual effect.
 
         :param json: (optional) dict (json) object to construct the object from
@@ -132,4 +132,4 @@ class InvalidVisualEffect(VisualEffect):
         :param applyCss: (optional) class to apply, defaults to 'invalid'
         :type applyCss: basestring
         """
-        super(InvalidVisualEffect, self).__init__(json=json, applyCss=applyCss, **kwargs)
+        super().__init__(json=json, applyCss=applyCss, **kwargs)
