@@ -2,28 +2,34 @@ import datetime
 import urllib
 import warnings
 from abc import abstractmethod
-from typing import Text, Union, Any, Dict, List, Optional
+from typing import Union, Any, Dict, List, Optional
 
 from pykechain.enums import FilterType, Category, PropertyType, ScopeStatus
 from pykechain.exceptions import IllegalArgumentError, NotFoundError
-from pykechain.models.input_checks import check_base, check_enum, check_type, check_text, \
-    check_datetime
+from pykechain.models.input_checks import (
+    check_base,
+    check_enum,
+    check_type,
+    check_text,
+    check_datetime,
+)
 from pykechain.models.widgets.enums import MetaWidget
 
 
-class BaseFilter(object):
+class BaseFilter:
     """Base class for any filters used in pykechain."""
 
     def __eq__(self, other):
         if isinstance(other, self.__class__):
             return self.__class__.write_options(filters=[self]) == self.__class__.write_options(
-                filters=[other])
+                filters=[other]
+            )
         else:
             return False
 
     @classmethod
     @abstractmethod
-    def parse_options(cls, options: Dict) -> List['BaseFilter']:  # pragma: no cover
+    def parse_options(cls, options: Dict) -> List["BaseFilter"]:  # pragma: no cover
         """
         Convert the dict & string-based definition of a filter to a list of Filter objects.
 
@@ -43,7 +49,7 @@ class BaseFilter(object):
         :returns options dict to be used to update the options dict of a property
         """
         if not all(isinstance(f, cls) for f in filters):
-            raise IllegalArgumentError("All `filters` must be of type `{}`".format(cls))
+            raise IllegalArgumentError(f"All `filters` must be of type `{cls}`")
 
 
 class PropertyValueFilter(BaseFilter):
@@ -57,7 +63,7 @@ class PropertyValueFilter(BaseFilter):
 
     def __init__(
         self,
-        property_model: Union[Text, 'Property'],
+        property_model: Union[str, "Property"],
         value: Any,
         filter_type: FilterType,
     ):
@@ -72,9 +78,9 @@ class PropertyValueFilter(BaseFilter):
         self.type = filter_type
 
     def __repr__(self):
-        return "PropertyValueFilter {}: {} ({})".format(self.type, self.value, self.id)
+        return f"PropertyValueFilter {self.type}: {self.value} ({self.id})"
 
-    def format(self) -> Text:
+    def format(self) -> str:
         """Format PropertyValueFilter as a string."""
         if isinstance(self.value, str):
             value = urllib.parse.quote(self.value)
@@ -82,9 +88,9 @@ class PropertyValueFilter(BaseFilter):
             value = str(self.value).lower()
         else:
             value = self.value
-        return "{}:{}:{}".format(self.id, value, self.type)
+        return f"{self.id}:{value}:{self.type}"
 
-    def validate(self, part_model: 'Part') -> None:
+    def validate(self, part_model: "Part") -> None:
         """
         Validate data of the PropertyValueFilter.
 
@@ -99,57 +105,84 @@ class PropertyValueFilter(BaseFilter):
         except NotFoundError:
             raise IllegalArgumentError(
                 "Property value filters can only be set on properties belonging to the selected "
-                "Part model.")
+                "Part model."
+            )
 
         if prop.category != Category.MODEL:
             raise IllegalArgumentError(
                 'Property value filters can only be set on Property models, received "{}".'.format(
-                    prop))
+                    prop
+                )
+            )
         else:
             property_type = prop.type
-            if property_type in (PropertyType.BOOLEAN_VALUE,
-                                 PropertyType.REFERENCES_VALUE,
-                                 PropertyType.ACTIVITY_REFERENCES_VALUE
-                                 ) and self.type != FilterType.EXACT:
-                warnings.warn("A PropertyValueFilter on a `{}` property should use "
-                              "filter type `{}`, not `{}`".format(property_type, FilterType.EXACT,
-                                                                  self.type), Warning)
-            elif property_type in (PropertyType.TEXT_VALUE,
-                                   PropertyType.CHAR_VALUE,
-                                   PropertyType.LINK_VALUE,
-                                   PropertyType.SINGLE_SELECT_VALUE,
-                                   PropertyType.USER_REFERENCES_VALUE,
-                                   PropertyType.SCOPE_REFERENCES_VALUE,
-                                   ) and self.type != FilterType.CONTAINS:
-                warnings.warn("A PropertyValueFilter on a `{}` property should use "
-                              "filter type `{}`, not `{}`".format(property_type,
-                                                                  FilterType.CONTAINS,
-                                                                  self.type), Warning)
-            elif property_type in (PropertyType.INT_VALUE,
-                                   PropertyType.FLOAT_VALUE,
-                                   PropertyType.DATE_VALUE,
-                                   PropertyType.DATETIME_VALUE
-                                   ) and self.type not in (
-                FilterType.LOWER_THAN_EQUAL,
-                FilterType.GREATER_THAN_EQUAL
+            if (
+                property_type
+                in (
+                    PropertyType.BOOLEAN_VALUE,
+                    PropertyType.REFERENCES_VALUE,
+                    PropertyType.ACTIVITY_REFERENCES_VALUE,
+                )
+                and self.type != FilterType.EXACT
             ):
-                warnings.warn("A PropertyValueFilter on a `{}` property should use "
-                              "filter type `{}` or `{}`, not `{}`".
-                              format(property_type,
-                                     FilterType.LOWER_THAN_EQUAL,
-                                     FilterType.GREATER_THAN_EQUAL,
-                                     self.type), Warning)
-            elif property_type in (PropertyType.MULTI_SELECT_VALUE,
-                                   ) and self.type != FilterType.CONTAINS_SET:
-                warnings.warn("A PropertyValueFilter on a `{}` property should use "
-                              "filter type `{}`, not `{}`".format(property_type,
-                                                                  FilterType.CONTAINS_SET,
-                                                                  self.type), Warning)
+                warnings.warn(
+                    "A PropertyValueFilter on a `{}` property should use "
+                    "filter type `{}`, not `{}`".format(
+                        property_type, FilterType.EXACT, self.type
+                    ),
+                    Warning,
+                )
+            elif (
+                property_type
+                in (
+                    PropertyType.TEXT_VALUE,
+                    PropertyType.CHAR_VALUE,
+                    PropertyType.LINK_VALUE,
+                    PropertyType.SINGLE_SELECT_VALUE,
+                    PropertyType.USER_REFERENCES_VALUE,
+                    PropertyType.SCOPE_REFERENCES_VALUE,
+                )
+                and self.type != FilterType.CONTAINS
+            ):
+                warnings.warn(
+                    "A PropertyValueFilter on a `{}` property should use "
+                    "filter type `{}`, not `{}`".format(
+                        property_type, FilterType.CONTAINS, self.type
+                    ),
+                    Warning,
+                )
+            elif property_type in (
+                PropertyType.INT_VALUE,
+                PropertyType.FLOAT_VALUE,
+                PropertyType.DATE_VALUE,
+                PropertyType.DATETIME_VALUE,
+            ) and self.type not in (FilterType.LOWER_THAN_EQUAL, FilterType.GREATER_THAN_EQUAL):
+                warnings.warn(
+                    "A PropertyValueFilter on a `{}` property should use "
+                    "filter type `{}` or `{}`, not `{}`".format(
+                        property_type,
+                        FilterType.LOWER_THAN_EQUAL,
+                        FilterType.GREATER_THAN_EQUAL,
+                        self.type,
+                    ),
+                    Warning,
+                )
+            elif (
+                property_type in (PropertyType.MULTI_SELECT_VALUE,)
+                and self.type != FilterType.CONTAINS_SET
+            ):
+                warnings.warn(
+                    "A PropertyValueFilter on a `{}` property should use "
+                    "filter type `{}`, not `{}`".format(
+                        property_type, FilterType.CONTAINS_SET, self.type
+                    ),
+                    Warning,
+                )
             else:
                 pass
 
     @classmethod
-    def parse_options(cls, options: Dict) -> List['PropertyValueFilter']:
+    def parse_options(cls, options: Dict) -> List["PropertyValueFilter"]:
         """
         Convert the dict & string-based definition of a property value filter to a list of PropertyValueFilter objects.
 
@@ -183,9 +216,7 @@ class PropertyValueFilter(BaseFilter):
         """
         super().write_options(filters=filters)
 
-        prefilters = {
-            "property_value": ",".join([pf.format() for pf in filters])
-        }
+        prefilters = {"property_value": ",".join([pf.format() for pf in filters])}
         options = {MetaWidget.PREFILTERS: prefilters}
 
         return options
@@ -214,17 +245,17 @@ class ScopeFilter(BaseFilter):
 
     def __init__(
         self,
-        tag: Optional[Text] = None,
+        tag: Optional[str] = None,
         status: Optional[ScopeStatus] = None,
-        name: Optional[Text] = None,
-        team: Optional[Union[Text, 'Team']] = None,
+        name: Optional[str] = None,
+        team: Optional[Union[str, "Team"]] = None,
         due_date_gte: Optional[datetime.datetime] = None,
         due_date_lte: Optional[datetime.datetime] = None,
         start_date_gte: Optional[datetime.datetime] = None,
         start_date_lte: Optional[datetime.datetime] = None,
         progress_gte: Optional[float] = None,
         progress_lte: Optional[float] = None,
-        **kwargs
+        **kwargs,
     ):
         """Create a ScopeFilter object."""
         from pykechain.models import Team
@@ -241,7 +272,7 @@ class ScopeFilter(BaseFilter):
             progress_gte,
             progress_lte,
         ]
-        if sum([p is not None for p in filters]) + len(kwargs) != 1:
+        if sum(p is not None for p in filters) + len(kwargs) != 1:
             raise IllegalArgumentError("Every ScopeFilter object must apply only 1 filter!")
 
         self.status = check_enum(status, ScopeStatus, "status")
@@ -259,32 +290,32 @@ class ScopeFilter(BaseFilter):
     def __repr__(self):
         _repr = "ScopeFilter: "
         if self.name:
-            _repr += "name: `{}`".format(self.name)
+            _repr += f"name: `{self.name}`"
         elif self.status:
-            _repr += "status `{}`".format(self.status)
+            _repr += f"status `{self.status}`"
         elif self.due_date_gte:
-            _repr += "due date greater or equal than: `{}`".format(self.due_date_gte)
+            _repr += f"due date greater or equal than: `{self.due_date_gte}`"
         elif self.due_date_lte:
-            _repr += "due date lesser or equal than: `{}`".format(self.due_date_lte)
+            _repr += f"due date lesser or equal than: `{self.due_date_lte}`"
         elif self.start_date_gte:
-            _repr += "start date greater or equal than: `{}`".format(self.start_date_gte)
+            _repr += f"start date greater or equal than: `{self.start_date_gte}`"
         elif self.start_date_lte:
-            _repr += "start date lesser or equal than: `{}`".format(self.start_date_lte)
+            _repr += f"start date lesser or equal than: `{self.start_date_lte}`"
         elif self.progress_gte:
-            _repr += "progress greater or equal than: {}%".format(self.progress_gte * 100)
+            _repr += f"progress greater or equal than: {self.progress_gte * 100}%"
         elif self.progress_lte:
-            _repr += "progress lesser or equal than: {}%".format(self.progress_lte * 100)
+            _repr += f"progress lesser or equal than: {self.progress_lte * 100}%"
         elif self.tag:
-            _repr += "tag `{}`".format(self.tag)
+            _repr += f"tag `{self.tag}`"
         elif self.team:
-            _repr += "team: `{}`".format(self.team)
+            _repr += f"team: `{self.team}`"
         else:
-            _repr += "{}".format(self.extra_filter)
+            _repr += f"{self.extra_filter}"
 
         return _repr
 
     @classmethod
-    def parse_options(cls, options: Dict) -> List['ScopeFilter']:
+    def parse_options(cls, options: Dict) -> List["ScopeFilter"]:
         """
         Convert the dict & string-based definition of a scope filter to a list of ScopeFilter objects.
 
@@ -344,7 +375,7 @@ class ScopeFilter(BaseFilter):
                         if field not in prefilters:
                             prefilters[field] = filter_value
                         else:
-                            prefilters[field] += ",{}".format(filter_value)
+                            prefilters[field] += f",{filter_value}"
                     else:
                         prefilters[field] = filter_value
 
