@@ -7,28 +7,33 @@ from tests.classes import TestBetamax
 
 
 class TestAttachment(TestBetamax):
-    test_dict = {'a': 1, 'b': 3}
-    project_root = os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__)).replace('\\', '/')))
+    test_dict = {"a": 1, "b": 3}
+    project_root = os.path.dirname(
+        os.path.dirname(os.path.dirname(os.path.abspath(__file__)).replace("\\", "/"))
+    )
 
     def setUp(self):
         super().setUp()
-        self.property_name = 'Plot Attachment'
+        self.property_name = "Plot Attachment"
 
-        self.root_model = self.project.model(name='Product')
-        self.part_model = self.root_model.add_model(name='__Testing attachments', multiplicity=Multiplicity.ONE_MANY)
+        self.root_model = self.project.model(name="Product")
+        self.part_model = self.root_model.add_model(
+            name="__Testing attachments", multiplicity=Multiplicity.ONE_MANY
+        )
         self.property_model = self.part_model.add_property(
-            name=self.property_name,
-            property_type=PropertyType.ATTACHMENT_VALUE
+            name=self.property_name, property_type=PropertyType.ATTACHMENT_VALUE
         )  # type: AttachmentProperty
 
-        self.property = self.part_model.instance().property(name=self.property_name)  # type: AttachmentProperty
+        self.property = self.part_model.instance().property(
+            name=self.property_name
+        )  # type: AttachmentProperty
 
     def tearDown(self):
         self.part_model.delete()
         super().tearDown()
 
     def test_retrieve_attachment(self):
-        data = ('data.json', json.dumps(self.test_dict), 'application/json')
+        data = ("data.json", json.dumps(self.test_dict), "application/json")
 
         self.property._upload(data)
 
@@ -39,7 +44,7 @@ class TestAttachment(TestBetamax):
     def test_retrieve_value(self):
         self.assertIsNone(self.property.value)
 
-        self.property.upload(self.project_root + '/requirements.txt')
+        self.property.upload(self.project_root + "/requirements.txt")
 
         self.assertIsNotNone(self.property.value)
 
@@ -49,18 +54,18 @@ class TestAttachment(TestBetamax):
 
     def test_set_value_not_a_path(self):
         with self.assertRaises(FileNotFoundError):
-            self.property.value = 'String must be a filepath'
+            self.property.value = "String must be a filepath"
 
     def test_upload(self):
-        self.property.upload(self.project_root + '/requirements.txt')
+        self.property.upload(self.project_root + "/requirements.txt")
 
-        requirements = self.project_root + '/requirements.txt'
+        requirements = self.project_root + "/requirements.txt"
         self.property.upload(requirements)
 
     # 1.11.1
     def test_clear_an_attachment_property(self):
         # setUp
-        self.property.upload(self.project_root + '/requirements.txt')
+        self.property.upload(self.project_root + "/requirements.txt")
 
         # testing
         self.assertTrue(self.property.has_value())
@@ -71,14 +76,14 @@ class TestAttachment(TestBetamax):
 
     def test_retrieve_filename_from_value(self):
         # setUp
-        self.property.upload(self.project_root + '/requirements.txt')
+        self.property.upload(self.project_root + "/requirements.txt")
 
         # testing
-        self.assertEqual(self.property.filename, 'requirements.txt')
+        self.assertEqual(self.property.filename, "requirements.txt")
 
     def test_has_value_true(self):
         # setUp
-        self.property.upload(self.project_root + '/requirements.txt')
+        self.property.upload(self.project_root + "/requirements.txt")
 
         # testing
         self.assertTrue(self.property.has_value())
@@ -91,7 +96,5 @@ class TestAttachment(TestBetamax):
         self.new_wheel = self.root_model.instance().add_with_properties(
             self.part_model,
             "new part",
-            update_dict={
-                self.property_name: self.project_root + '/requirements.txt'
-            },
+            update_dict={self.property_name: self.project_root + "/requirements.txt"},
         )
