@@ -6,23 +6,26 @@ from pykechain.models import DatetimeProperty, Property
 from tests.classes import TestBetamax
 
 
-class TestDateTime(TestBetamax):
+class TestPropertyDateTime(TestBetamax):
     example_time = datetime.datetime.now()
     NAME = "_TESTING DATE"
 
     def setUp(self) -> None:
-        super(TestDateTime, self).setUp()
+        super().setUp()
 
-        self.bike_model = self.project.model('Bike')
+        self.bike_model = self.project.model("Bike")
         self.property_model = self.bike_model.add_property(
-            name=self.NAME, property_type=PropertyType.DATETIME_VALUE)  # type: DatetimeProperty
-        self.property = self.project.part('Bike').property(name=self.NAME)  # type: DatetimeProperty
+            name=self.NAME, property_type=PropertyType.DATETIME_VALUE
+        )  # type: DatetimeProperty
+        self.property = self.project.part("Bike").property(
+            name=self.NAME
+        )  # type: DatetimeProperty
 
         self.property.value = self.example_time
 
     def tearDown(self):
         self.property_model.delete()
-        super(TestDateTime, self).tearDown()
+        super().tearDown()
 
     def test_get_datetime(self):
         value = self.property.value
@@ -37,7 +40,7 @@ class TestDateTime(TestBetamax):
 
     def test_set_value_non_datetime(self):
         with self.assertRaises(IllegalArgumentError):
-            self.property.value = '3'
+            self.property.value = "3"
 
     def test_set_value(self):
         self.property.value = self.example_time
@@ -58,9 +61,11 @@ class TestDateTime(TestBetamax):
         self.assertTrue(live_property.has_value())
 
     def test_value_via_part(self):
-        self.bike_model.update(update_dict={
-            self.NAME: self.example_time,
-        })
+        self.bike_model.update(
+            update_dict={
+                self.NAME: self.example_time,
+            }
+        )
 
     def test_to_datetime(self):
         date_time_value = self.property.to_datetime()
@@ -73,4 +78,3 @@ class TestDateTime(TestBetamax):
         iso_format_datetime = DatetimeProperty.to_iso_format(date_time_value)
 
         self.assertIsInstance(iso_format_datetime, str)
-
