@@ -1,47 +1,46 @@
 import os
 import warnings
 from datetime import datetime
-from unittest import skip, skipIf
+from unittest import skip
 
 import pytest
 import pytz
 import requests
 
 from pykechain.enums import (
-    ActivityType,
-    ActivityStatus,
     ActivityClassification,
-    Category,
-    activity_root_name_by_classification,
     ActivityRootNames,
-    PaperSize,
-    PaperOrientation,
-    NotificationEvent,
+    ActivityStatus,
+    ActivityType,
+    Category,
     Multiplicity,
+    NotificationEvent,
+    PaperOrientation,
+    PaperSize,
     PropertyType,
+    activity_root_name_by_classification,
 )
 from pykechain.exceptions import (
-    NotFoundError,
-    MultipleFoundError,
-    IllegalArgumentError,
     APIError,
+    IllegalArgumentError,
+    MultipleFoundError,
+    NotFoundError,
 )
 from pykechain.models import Activity
 from pykechain.models.representations import CustomIconRepresentation
-from pykechain.utils import temp_chdir, slugify_ref
+from pykechain.utils import slugify_ref, temp_chdir
 from tests.classes import TestBetamax
-from tests.utils import TEST_FLAG_IS_WIM2
 
 ISOFORMAT = "%Y-%m-%dT%H:%M:%SZ"
 ISOFORMAT_HIGHPRECISION = "%Y-%m-%dT%H:%M:%S.%fZ"
 
 
 class TestActivityConstruction(TestBetamax):
-
     def setUp(self):
         super().setUp()
         self.process = self.project.create_activity(
-            name="__Test process", activity_type=ActivityType.PROCESS,
+            name="__Test process",
+            activity_type=ActivityType.PROCESS,
         )
         self.task = None
 
@@ -105,7 +104,8 @@ class TestActivityConstruction(TestBetamax):
         )
 
         new_task = self.process.create(
-            name="__Testing task", activity_type=ActivityType.TASK,
+            name="__Testing task",
+            activity_type=ActivityType.TASK,
         )
 
         current_children = self.process.children()
@@ -118,11 +118,13 @@ class TestActivityConstruction(TestBetamax):
         )
 
     # NOTE: Change this test once we release the FORMS backend to production or a testing setup.
-    @skip("This test does not work as the testing backend does not have FORMS in the codebase")
+    @skip(
+        "This test does not work as the testing backend does not have FORMS in the codebase"
+    )
     def test_create_with_classification(self):
 
         for classification in ActivityClassification.values():
-            with self.subTest(msg="Classification: {}".format(classification)):
+            with self.subTest(msg=f"Classification: {classification}"):
                 # setUp 1
                 root_name = activity_root_name_by_classification[classification]
                 root = self.project.activity(name=root_name)
@@ -134,7 +136,7 @@ class TestActivityConstruction(TestBetamax):
                 # setUp 2
                 task = self.client.create_activity(
                     parent=root,
-                    name="{}".format(classification),
+                    name=f"{classification}",
                     classification=classification,
                 )
 
@@ -147,13 +149,15 @@ class TestActivityConstruction(TestBetamax):
     def test_create_with_incorrect_classification(self):
         with self.assertRaises(IllegalArgumentError):
             self.project.create_activity(
-                name="Impossible classification", classification="Gummy bears",
+                name="Impossible classification",
+                classification="Gummy bears",
             )
 
     def test_create_with_incorrect_parent(self):
         with self.assertRaises(IllegalArgumentError):
             self.client.create_activity(
-                name="Impossible parent", parent="Darth vader",
+                name="Impossible parent",
+                parent="Darth vader",
             )
 
     def test_create_with_task_as_parent(self):
@@ -227,17 +231,22 @@ class TestActivityClone(TestBetamax):
 
     def test_parent_id(self):
         second_process = self.project.create_activity(
-            name="__Test process 2", activity_type=ActivityType.PROCESS,
+            name="__Test process 2",
+            activity_type=ActivityType.PROCESS,
         )
         self.bucket.append(second_process)
 
-        clone = self.task.clone(parent=second_process,)
+        clone = self.task.clone(
+            parent=second_process,
+        )
 
         self.assertNotEqual(self.task.parent_id, clone.parent_id)
 
     def test_update(self):
         new_name = "__TEST TASK RENAMED"
-        clone = self.task.clone(update_dict=dict(name=new_name),)
+        clone = self.task.clone(
+            update_dict=dict(name=new_name),
+        )
 
         self.assertEqual(new_name, clone.name)
 
@@ -301,7 +310,8 @@ class TestActivityCloneParts(TestBetamax):
         self.bike_model = self.project.model("Bike")
         self.bike_instance = self.bike_model.instance()
         wm.add_propertygrid_widget(
-            part_instance=self.bike_instance, all_readable=True,
+            part_instance=self.bike_instance,
+            all_readable=True,
         )
 
         # Create target parents to move to
@@ -367,13 +377,14 @@ class TestActivityCloneParts(TestBetamax):
         self.assertNotIn(
             "Bike",
             {c.name for c in new_children},
-            msg="Bike should not have been copied over. "
-            "Actually it is not copied over, it is moved to the parent_instance",
+            msg=(
+                "Bike should not have been copied over. "
+                "Actually it is not copied over, it is moved to the parent_instance"
+            ),
         )
 
 
 class TestActivities(TestBetamax):
-
     NAME = "__TEST ACTIVITY"
 
     def setUp(self):
@@ -541,35 +552,52 @@ class TestActivities(TestBetamax):
     # test added due to #847 - providing no inputs overwrites values
     def test_edit_activity_clearing_values(self):
         # setup
-        initial_name = 'Pykechain testing task'
-        initial_description = 'Task created to test editing.'
+        initial_name = "Pykechain testing task"
+        initial_description = "Task created to test editing."
         initial_start_date = datetime(2018, 12, 5, tzinfo=None)
         initial_due_date = datetime(2018, 12, 8, tzinfo=None)
-        initial_tags = ['tag_one', 'tag_two']
+        initial_tags = ["tag_one", "tag_two"]
         initial_assignee = self.client.user(username="testuser")
 
-        self.task.edit(name=initial_name, description=initial_description, tags=initial_tags,
-                       start_date=initial_start_date, due_date=initial_due_date, assignees=[initial_assignee.username])
+        self.task.edit(
+            name=initial_name,
+            description=initial_description,
+            tags=initial_tags,
+            start_date=initial_start_date,
+            due_date=initial_due_date,
+            assignees=[initial_assignee.username],
+        )
 
         # Edit without mentioning values, everything should stay the same
-        new_name = 'New name for task'
+        new_name = "New name for task"
         self.task.edit(name=new_name)
 
         # testing
         self.assertEqual(self.task.name, new_name)
         self.assertEqual(self.task.description, initial_description)
-        self.assertEqual(self.task.start_date.strftime("%Y/%m/%d, %H:%M:%S"),
-                         initial_start_date.strftime("%Y/%m/%d, %H:%M:%S"))
-        self.assertEqual(self.task.due_date.strftime("%Y/%m/%d, %H:%M:%S"),
-                         initial_due_date.strftime("%Y/%m/%d, %H:%M:%S"))
+        self.assertEqual(
+            self.task.start_date.strftime("%Y/%m/%d, %H:%M:%S"),
+            initial_start_date.strftime("%Y/%m/%d, %H:%M:%S"),
+        )
+        self.assertEqual(
+            self.task.due_date.strftime("%Y/%m/%d, %H:%M:%S"),
+            initial_due_date.strftime("%Y/%m/%d, %H:%M:%S"),
+        )
         self.assertEqual(self.task.tags, initial_tags)
 
         # Edit with clearing the values, name and status cannot be cleared
-        self.task.edit(name=None, description=None, tags=None, start_date=None, due_date=None, status=None,
-                       assignees=None)
+        self.task.edit(
+            name=None,
+            description=None,
+            tags=None,
+            start_date=None,
+            due_date=None,
+            status=None,
+            assignees=None,
+        )
         self.task.refresh()
         self.assertEqual(self.task.name, new_name)
-        self.assertEqual(self.task.description, str())
+        self.assertEqual(self.task.description, "")
         self.assertEqual(self.task.start_date, None)
         self.assertEqual(self.task.due_date, None)
         self.assertEqual(self.task.assignees, list())
@@ -602,7 +630,7 @@ class TestActivities(TestBetamax):
 
         self.assertIsInstance(all_tasks, list)
         self.assertEqual(
-            12, len(all_tasks), msg="Number of tasks has changed, expected 12."
+            13, len(all_tasks), msg="Number of tasks has changed, expected 13."
         )
 
     def test_retrieve_activity_by_id(self):
@@ -632,10 +660,6 @@ class TestActivities(TestBetamax):
         self.assertIn(task.id, [sibling.id for sibling in siblings])
         self.assertEqual(1, len(siblings))
 
-    @skipIf(
-        not TEST_FLAG_IS_WIM2,
-        reason="This tests is designed for WIM version 2, expected to fail on old WIM",
-    )
     def test_activity_without_scope_id_will_fix_itself(self):
         specify_wheel_diam_cripled = self.project.activity(
             name="Specify wheel diameter", fields="id,name,status"
@@ -652,20 +676,6 @@ class TestActivities(TestBetamax):
         ):
             self.project.create_activity(name="New", activity_type="DEFUNCTActivity")
 
-#
-# @skipIf(not TEST_FLAG_IS_WIM2, reason="This tests is designed for WIM version 2, expected to fail on older WIM")
-# class TestActivitiesWIM2(TestBetamax):
-#
-#     def setUp(self):
-#         super().setUp()
-#         self.root = self.project.activity(ActivityRootNames.WORKFLOW_ROOT)
-#         self.task = self.root.create(name='test task', activity_type=ActivityType.TASK)
-#
-#     def tearDown(self):
-#         if self.task:
-#             self.task.delete()
-#         super().tearDown()
-
     # 2.0 new activity
     # noinspection PyTypeChecker
     def test_edit_activity_assignee(self):
@@ -775,12 +785,15 @@ class TestActivities(TestBetamax):
         self.assertFalse(subprocess.is_task())
 
     def test_activity_assignees_list(self):
+        test_user = self.client.user(username="testuser")
+        self.task.edit(assignees_ids=[test_user.id])
+        self.task.refresh()
+
         list_of_assignees_in_data = self.task._json_data.get("assignees_ids")
         assignees_list = self.task.assignees
 
         self.assertSetEqual(
-
-            set(list_of_assignees_in_data), set([u.id for u in assignees_list])
+            set(list_of_assignees_in_data), {u.id for u in assignees_list}
         )
 
     def test_activity_assignees_list_no_assignees_gives_empty_list(self):
@@ -889,12 +902,12 @@ class TestActivityDownloadAsPDF(TestBetamax):
         # setUp
         activity_name = "Task - Form"
         activity = self.project.activity(name=activity_name)
+        user = self.client.user(id=3)  # testmanager
 
         # testing
         with temp_chdir() as target_dir:
             pdf_file = activity.download_as_pdf(
-                target_dir=target_dir,
-                pdf_filename="pdf_file",
+                target_dir=target_dir, pdf_filename="pdf_file", user=user
             )
             self.assertTrue(os.path.exists(pdf_file))
 
